"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.useStepperForm = void 0;
var _react = require("react");
var _StepperForm = require("../../components/StepperForm/StepperForm.utils");
var _useStepperForm = require("./useStepperForm.types");
const handleStepChange = (state, navigation, direction) => {
  const {
    from,
    to
  } = navigation;
  const stepState = state.find(step => step.key === from);
  if (!stepState) {
    return state;
  }
  const newState = [...state];
  const index = state.indexOf(stepState);
  newState[index].navigation = {
    ...stepState.navigation,
    ...(direction === _useStepperForm.NavigationDirection.NEXT ? {
      next: to
    } : {
      previous: to
    })
  };
  return newState;
};
const disableStep = (state, stepKey, cause) => {
  var _stepState$navigation, _stepState$navigation2;
  const stepState = state.find(step => step.key === stepKey);
  if (!stepState) {
    return state;
  }
  const nextStep = (_stepState$navigation = stepState.navigation) === null || _stepState$navigation === void 0 ? void 0 : _stepState$navigation.next;
  const previousStep = (_stepState$navigation2 = stepState.navigation) === null || _stepState$navigation2 === void 0 ? void 0 : _stepState$navigation2.previous;
  const index = state.indexOf(stepState);
  let newState = [...state];
  newState[index].navigation = {
    ...stepState.navigation,
    disableCause: cause
  };
  if (nextStep) {
    newState = handleStepChange(newState, {
      from: nextStep,
      to: previousStep
    }, _useStepperForm.NavigationDirection.PREVIOUS);
  }
  if (previousStep) {
    newState = handleStepChange(newState, {
      from: previousStep,
      to: nextStep
    }, _useStepperForm.NavigationDirection.NEXT);
  }
  return newState;
};
const enableStep = (state, stepKey) => {
  var _stepState$navigation3, _stepState$navigation4, _newState$index$navig;
  const stepState = state.find(step => step.key === stepKey);
  if (!stepState) {
    return state;
  }
  const nextStep = (_stepState$navigation3 = stepState.navigation) === null || _stepState$navigation3 === void 0 ? void 0 : _stepState$navigation3.next;
  const previousStep = (_stepState$navigation4 = stepState.navigation) === null || _stepState$navigation4 === void 0 ? void 0 : _stepState$navigation4.previous;
  const index = state.indexOf(stepState);
  let newState = [...state];
  (_newState$index$navig = newState[index].navigation) === null || _newState$index$navig === void 0 ? true : delete _newState$index$navig.disableCause;
  if (nextStep) {
    newState = handleStepChange(newState, {
      from: nextStep,
      to: stepKey
    }, _useStepperForm.NavigationDirection.PREVIOUS);
  }
  if (previousStep) {
    newState = handleStepChange(newState, {
      from: previousStep,
      to: stepKey
    }, _useStepperForm.NavigationDirection.NEXT);
  }
  return newState;
};
const onChangeStep = (stepperState, stepKey) => {
  const stepToGo = stepperState.find(step => step.key === stepKey);
  if (stepToGo) {
    return stepperState.indexOf(stepToGo);
  }
  return;
};
const useStepperForm = (steps, stepIndex, onSubmit) => {
  const [currentStep, setCurrentStep] = (0, _react.useState)(stepIndex);
  const [stepperSteps, setStepperSteps] = (0, _react.useState)((0, _StepperForm.getStepperState)(steps));
  const currentNavigation = stepperSteps[currentStep].navigation;
  return {
    currentStep,
    disableStep: (stepKey, cause) => setStepperSteps(disableStep(stepperSteps, stepKey, cause)),
    enableStep: stepKey => setStepperSteps(enableStep(stepperSteps, stepKey)),
    onNextStep: () => {
      var _ref;
      setCurrentStep((_ref = currentNavigation && onChangeStep(stepperSteps, currentNavigation.next)) !== null && _ref !== void 0 ? _ref : currentStep);
      if (!(currentNavigation !== null && currentNavigation !== void 0 && currentNavigation.next)) {
        onSubmit(currentStep);
      }
    },
    onPreviousStep: () => {
      var _ref2;
      return setCurrentStep((_ref2 = currentNavigation && onChangeStep(stepperSteps, currentNavigation.previous)) !== null && _ref2 !== void 0 ? _ref2 : currentStep);
    },
    stepperSteps
  };
};
exports.useStepperForm = useStepperForm;
//# sourceMappingURL=useStepperForm.hook.js.map