"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.initStepper = initStepper;
exports.proceedLoadingEvent = proceedLoadingEvent;
exports.removeStepper = removeStepper;
var _Stepper = require("../Stepper.constants");
function checkResourceParameters(resourceType, resourceId) {
  if (!resourceType) {
    throw new Error('Stepper Reducer : resourceType should be present in the action');
  }
  if (!resourceId) {
    throw new Error('Stepper Reducer : resourceId should be present in the action');
  }
}

/**
 * This function init the store for some loading steps component
 * @param {string} resourceType the resource type we load
 * @param {string} resourceId the id of the resource we load
 * @param {array} steps the steps we have to load
 */
function initStepper(resourceType, resourceId, steps = []) {
  checkResourceParameters(resourceType, resourceId);
  return {
    type: _Stepper.LOADING_STEPS_INIT,
    resourceType,
    resourceId,
    steps
  };
}

/**
 * This function generate an action to tell the loading that we have
 * intercept some event to proceed in the loading process
 * @param {string} resourceType the resource type we load
 * @param {string} resourceId the id of the resource we load
 * @param {string} event event catch
 */
function proceedLoadingEvent(resourceType, resourceId, event, messageLabel) {
  checkResourceParameters(resourceType, resourceId);
  return {
    type: _Stepper.LOADING_STEPS_PROCEED_EVENT,
    resourceType,
    resourceId,
    event,
    message: {
      label: messageLabel
    }
  };
}

/**
 * This function return an action to remove a loading from the store
 * @param {string} resourceType the resource type we load
 * @param {string} resourceId the id of the resource we load
 */
function removeStepper(resourceType, resourceId) {
  checkResourceParameters(resourceType, resourceId);
  return {
    type: _Stepper.LOADING_STEPS_REMOVE,
    resourceType,
    resourceId
  };
}
//# sourceMappingURL=Stepper.actions.js.map